﻿"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BodyPropParameterParser = void 0;
const common_1 = require("@kitajs/common");
const helpers_1 = require("../schema/helpers");
const nodes_1 = require("../util/nodes");
const syntax_1 = require("../util/syntax");
class BodyPropParameterParser {
    config;
    schema;
    constructor(config, schema) {
        this.config = config;
        this.schema = schema;
    }
    supports(param) {
        return (0, nodes_1.getTypeNodeName)(param) === 'BodyProp';
    }
    parse(param, route) {
        if (route.method === 'GET') {
            throw new common_1.BodyInGetRequestError(param.type || param);
        }
        // The $ref property is set when using the Body parameter
        if (route.schema.body?.$ref) {
            throw new common_1.ParameterConflictError('Body', 'BodyProp', param.type || param);
        }
        const [type] = (0, nodes_1.getParameterGenerics)(param);
        if (!type) {
            throw new common_1.InvalidParameterUsageError('You must specify a type for the BodyProp parameter.', param.type || param);
        }
        const name = (0, nodes_1.getParameterName)(param, 1);
        if (name.includes('.')) {
            throw new common_1.InvalidParameterUsageError('You cannot have dots in the BodyProp name. Use the Body parameter for deep objects.', param.type || param);
        }
        const optional = (0, nodes_1.isParamOptional)(param);
        (0, helpers_1.mergeSchema)(route, {
            body: {
                type: 'object',
                properties: { [name]: this.schema.consumeNodeSchema(type) },
                required: optional ? [] : [name],
                additionalProperties: this.config.generatorConfig.additionalProperties
            }
        });
        return {
            name: BodyPropParameterParser.name,
            value: (0, syntax_1.buildAccessProperty)(common_1.kRequestParam, 'body', name)
        };
    }
}
exports.BodyPropParameterParser = BodyPropParameterParser;
//# sourceMappingURL=body-prop.js.map