﻿"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BodyParameterParser = void 0;
const common_1 = require("@kitajs/common");
const helpers_1 = require("../schema/helpers");
const nodes_1 = require("../util/nodes");
const syntax_1 = require("../util/syntax");
class BodyParameterParser {
    schema;
    constructor(schema) {
        this.schema = schema;
    }
    supports(param) {
        return (0, nodes_1.getTypeNodeName)(param) === 'Body';
    }
    parse(param, route) {
        if (route.method === 'GET') {
            throw new common_1.BodyInGetRequestError(param.type || param);
        }
        // Properties are defined when using the BodyProp parameter
        if (route.schema.body?.properties) {
            throw new common_1.ParameterConflictError('BodyProp', 'Body', param.type || param);
        }
        const [type] = (0, nodes_1.getParameterGenerics)(param);
        if (!type) {
            throw new common_1.InvalidParameterUsageError('You must specify a type for the Body parameter.', param.type || param);
        }
        (0, helpers_1.mergeSchema)(route, {
            body: this.schema.consumeNodeSchema(type)
        });
        return {
            name: BodyParameterParser.name,
            value: (0, syntax_1.buildAccessProperty)(common_1.kRequestParam, 'body')
        };
    }
}
exports.BodyParameterParser = BodyParameterParser;
//# sourceMappingURL=body.js.map