﻿"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CookieParameterParser = void 0;
const common_1 = require("@kitajs/common");
const nodes_1 = require("../util/nodes");
const syntax_1 = require("../util/syntax");
class CookieParameterParser {
    collector;
    constructor(collector) {
        this.collector = collector;
    }
    supports(param) {
        return (0, nodes_1.getTypeNodeName)(param) === 'Cookie';
    }
    parse(param, _route) {
        if (!this.collector.getPlugin('fastifyCookie')) {
            this.collector.addPlugin('fastifyCookie', {
                name: 'fastifyCookie',
                importUrl: '@fastify/cookie',
                options: {}
            });
        }
        const name = (0, nodes_1.getParameterName)(param, 0);
        const value = (0, syntax_1.buildAccessProperty)(common_1.kRequestParam, 'cookies', name);
        const optional = (0, nodes_1.isParamOptional)(param);
        return {
            name: CookieParameterParser.name,
            value: value,
            helper: optional
                ? undefined
                : // TODO: Add a better error, maybe import one from fastify?
                    `if (${value} === undefined) { throw new Error('Missing cookie ${name}') };`
        };
    }
}
exports.CookieParameterParser = CookieParameterParser;
//# sourceMappingURL=cookie.js.map