﻿"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ProviderParameterParser = void 0;
const common_1 = require("@kitajs/common");
const ts_json_schema_generator_1 = require("ts-json-schema-generator");
const nodes_1 = require("../util/nodes");
const syntax_1 = require("../util/syntax");
const provider_generics_1 = require("./provider-generics");
class ProviderParameterParser {
    collector;
    constructor(collector) {
        this.collector = collector;
    }
    supports(param) {
        const name = (0, nodes_1.getTypeNodeName)(param);
        return !!name && !!this.collector.getProvider(name);
    }
    async parse(param, route, _node, index) {
        const name = (0, nodes_1.getTypeNodeName)(param);
        const provider = this.collector.getProvider(name);
        const parameters = await provider.parseParameters(route, param);
        const providerGenericsIndex = parameters.findIndex((p) => p.name === provider_generics_1.ProviderGenericsParameterParser.name);
        // Changes the default [] to the generics passed to the Provider
        if (providerGenericsIndex !== -1) {
            const generics = (0, nodes_1.getParameterGenerics)(param);
            const arr = [];
            for (const generic of generics) {
                // 01, 'str', true
                if (!ts_json_schema_generator_1.ts.isLiteralTypeNode(generic)) {
                    throw new common_1.InvalidProviderGenericTypeError(generic);
                }
                arr.push(generic.literal.getText());
            }
            parameters[providerGenericsIndex].value = `[${arr.join(', ')}]`;
        }
        const value = `param${index + parameters.length}`;
        return {
            name: ProviderParameterParser.name,
            value,
            providerName: provider.type,
            imports: [{ name: provider.type, path: provider.providerPath }].concat(parameters.flatMap((p) => p.imports || [])),
            schemaTransformer: provider.schemaTransformer &&
                (providerGenericsIndex !== -1 ? [parameters[providerGenericsIndex].value] : provider.schemaTransformer),
            helper: `${(0, syntax_1.joinParameters)(parameters)}
const ${value} = ${provider.async ? 'await ' : ''}${provider.type}.default(${parameters
                .map((p) => p.value)
                .join(',')});`.trim()
        };
    }
}
exports.ProviderParameterParser = ProviderParameterParser;
//# sourceMappingURL=custom.js.map