﻿"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FileParameterParser = void 0;
const common_1 = require("@kitajs/common");
const helpers_1 = require("../schema/helpers");
const nodes_1 = require("../util/nodes");
const syntax_1 = require("../util/syntax");
class FileParameterParser {
    config;
    collector;
    constructor(config, collector) {
        this.config = config;
        this.collector = collector;
    }
    supports(param) {
        return (0, nodes_1.getTypeNodeName)(param) === 'File' || (0, nodes_1.getTypeNodeName)(param) === 'SavedFile';
    }
    parse(param, route) {
        // Adds fastify sensible plugin
        if (!this.collector.getPlugin('fastifyMultipart')) {
            this.collector.addPlugin('fastifyMultipart', {
                name: 'fastifyMultipart',
                importUrl: '@fastify/multipart',
                options: { attachFieldsToBody: true }
            });
        }
        if (route.method === 'GET') {
            throw new common_1.BodyInGetRequestError(param.type || param);
        }
        const name = (0, nodes_1.getParameterName)(param, 0);
        const isSavedFile = (0, nodes_1.getTypeNodeName)(param) === 'SavedFile';
        // Adds multipart/form-data to the consumes array
        route.schema.consumes = ['multipart/form-data'];
        const optional = (0, nodes_1.isParamOptional)(param);
        (0, helpers_1.mergeSchema)(route, {
            body: {
                type: 'object',
                properties: {
                    // @ts-expect-error - isFile is a internal property of @fastify/multipart
                    [name]: { isFile: true }
                },
                required: optional ? [] : [name],
                additionalProperties: this.config.generatorConfig.additionalProperties
            }
        });
        if (isSavedFile) {
            let helper;
            // No previous file parameters, we need to add the helper
            if (!route.parameters.find((f) => f.name === FileParameterParser.name)) {
                helper = `await ${common_1.kRequestParam}.saveRequestFiles()`;
            }
            return {
                name: FileParameterParser.name,
                value: `${common_1.kRequestParam}.savedRequestFiles.find(file => file.fieldname === '${name}')`,
                helper: helper
            };
        }
        return {
            name: FileParameterParser.name,
            value: (0, syntax_1.buildAccessProperty)(common_1.kRequestParam, 'body', name)
        };
    }
}
exports.FileParameterParser = FileParameterParser;
//# sourceMappingURL=file.js.map