﻿"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildParameterParser = void 0;
const body_1 = require("./body");
const body_prop_1 = require("./body-prop");
const chain_1 = require("./chain");
const cookie_1 = require("./cookie");
const custom_1 = require("./custom");
const errors_1 = require("./errors");
const fastify_1 = require("./fastify");
const file_1 = require("./file");
const header_1 = require("./header");
const path_1 = require("./path");
const provider_generics_1 = require("./provider-generics");
const query_1 = require("./query");
const suspense_id_1 = require("./suspense-id");
const this_1 = require("./this");
function buildParameterParser(config, schema, collector) {
    const chain = new chain_1.ChainParameterParser();
    // Adds custom parsers defined by the user
    config.parameterParserAugmentor?.(chain);
    // Adds default parsers
    chain
        .add(new fastify_1.FastifyParameterParser())
        .add(new query_1.QueryParameterParser(schema, config))
        .add(new body_1.BodyParameterParser(schema))
        .add(new body_prop_1.BodyPropParameterParser(config, schema))
        .add(new custom_1.ProviderParameterParser(collector))
        .add(new path_1.PathParameterParser(schema, config))
        .add(new header_1.HeaderParameterParser(config))
        .add(new cookie_1.CookieParameterParser(collector))
        .add(new this_1.ThisParameterParser())
        .add(new suspense_id_1.SuspenseIdParameterParser())
        .add(new provider_generics_1.ProviderGenericsParameterParser())
        .add(new file_1.FileParameterParser(config, collector))
        .add(new errors_1.ErrorsParameterParser(collector));
    return chain;
}
exports.buildParameterParser = buildParameterParser;
//# sourceMappingURL=index.js.map