﻿"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PathParameterParser = void 0;
const common_1 = require("@kitajs/common");
const ts_json_schema_generator_1 = require("ts-json-schema-generator");
const helpers_1 = require("../schema/helpers");
const nodes_1 = require("../util/nodes");
const syntax_1 = require("../util/syntax");
class PathParameterParser {
    builder;
    config;
    constructor(builder, config) {
        this.builder = builder;
        this.config = config;
    }
    supports(param) {
        return (0, nodes_1.getTypeNodeName)(param) === 'Path';
    }
    parse(param, route) {
        const optional = (0, nodes_1.isParamOptional)(param);
        if (optional) {
            throw new common_1.InvalidParameterUsageError('Path parameter cannot be optional', param.type || param);
        }
        const name = (0, nodes_1.getParameterName)(param, 1);
        const [type] = (0, nodes_1.getParameterGenerics)(param);
        let schema;
        if (type) {
            const primitive = this.builder.toPrimitive(type);
            if (!primitive) {
                throw new common_1.InvalidParameterUsageError('Path parameter must be a primitive type', param.type || param);
            }
            if (primitive instanceof ts_json_schema_generator_1.ArrayType) {
                throw new common_1.InvalidParameterUsageError('Path parameter cannot be an array', param.type || param);
            }
            schema = this.builder.formatDefinition(primitive);
        }
        else {
            schema = { type: 'string' };
        }
        (0, helpers_1.mergeSchema)(route, {
            params: {
                type: 'object',
                properties: { [name]: schema },
                required: [name],
                additionalProperties: this.config.generatorConfig.additionalProperties
            }
        });
        return {
            name: PathParameterParser.name,
            value: (0, syntax_1.buildAccessProperty)(common_1.kRequestParam, 'params', name)
        };
    }
}
exports.PathParameterParser = PathParameterParser;
//# sourceMappingURL=path.js.map