﻿"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.QueryParameterParser = void 0;
const common_1 = require("@kitajs/common");
const ts_json_schema_generator_1 = require("ts-json-schema-generator");
const helpers_1 = require("../schema/helpers");
const nodes_1 = require("../util/nodes");
const syntax_1 = require("../util/syntax");
class QueryParameterParser {
    schemaBuilder;
    config;
    constructor(schemaBuilder, config) {
        this.schemaBuilder = schemaBuilder;
        this.config = config;
    }
    supports(param) {
        return (0, nodes_1.getTypeNodeName)(param) === 'Query';
    }
    parse(param, route, _node, _index) {
        const [type, genericName] = (0, nodes_1.getParameterGenerics)(param);
        const primitiveType = type === undefined ? new ts_json_schema_generator_1.StringType() : this.schemaBuilder.toPrimitive(type);
        // Simple primitive parameter, can be grouped with other Query parameters
        if (primitiveType) {
            if (route.schema.querystring?.$ref) {
                throw new common_1.QueryMixError(param);
            }
            const optional = (0, nodes_1.isParamOptional)(param);
            const name = (0, nodes_1.getParameterName)(param, 1);
            (0, helpers_1.mergeSchema)(route, {
                querystring: {
                    type: 'object',
                    properties: {
                        [name]: this.schemaBuilder.formatDefinition(primitiveType)
                    },
                    required: optional ? [] : [name],
                    additionalProperties: this.config.generatorConfig.additionalProperties
                }
            });
            return {
                name: QueryParameterParser.name,
                value: (0, syntax_1.buildAccessProperty)(common_1.kRequestParam, 'query', name)
            };
        }
        if (genericName) {
            throw new common_1.InvalidParameterUsageError('You cannot give a name to a complex query object', param.type || param);
        }
        // Already used a query primitive query parameter
        if (route.schema.querystring?.properties) {
            throw new common_1.QueryMixError(param);
        }
        // Already used a query extended query parameter
        if (route.schema.querystring?.$ref) {
            throw new common_1.ParameterConflictError('Query<{...}>', 'Query<{...}>', param.type || param);
        }
        (0, helpers_1.mergeSchema)(route, {
            querystring: this.schemaBuilder.consumeNodeSchema(type)
        });
        return {
            name: QueryParameterParser.name,
            value: (0, syntax_1.buildAccessProperty)(common_1.kRequestParam, 'query')
        };
    }
}
exports.QueryParameterParser = QueryParameterParser;
//# sourceMappingURL=query.js.map