﻿"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ThisParameterParser = void 0;
const common_1 = require("@kitajs/common");
const ts_json_schema_generator_1 = require("ts-json-schema-generator");
const nodes_1 = require("../util/nodes");
class ThisParameterParser {
    supports(param) {
        return (0, nodes_1.getTypeNodeName)(param) === 'Use' || (0, nodes_1.getTypeName)(param) === 'this';
    }
    parse(param, route, fn, index) {
        const isThis = (0, nodes_1.getTypeName)(param) === 'this' && index === 0;
        const isUse = (0, nodes_1.getTypeNodeName)(param) === 'Use';
        // other parameter with Use type
        if (!isThis && isUse) {
            throw new common_1.InvalidParameterUsageError('The `Use<>` parameter can only be bound to the `this` keyword.', param.type || param);
        }
        // this parameter with other type
        if (!isUse && isThis) {
            throw new common_1.InvalidParameterUsageError('The `this` parameter can only be used with the `Use<>` type.', param.type || param);
        }
        const [config] = (0, nodes_1.getParameterGenerics)(param);
        if (!config) {
            throw new common_1.InvalidParameterUsageError('The `this` parameter must be used with a configuration type.', param.type || param);
        }
        if (!ts_json_schema_generator_1.ts.isTypeQueryNode(config) && !ts_json_schema_generator_1.ts.isTupleTypeNode(config)) {
            throw new common_1.InvalidParameterUsageError('The `this` parameter must be used `typeof` reference or a literal tuple of `typeof` references', param.type || param);
        }
        if (route.options) {
            throw new common_1.RouteOptionsAlreadyDefinedError(fn.name || fn);
        }
        // Single typeof reference
        if (ts_json_schema_generator_1.ts.isTypeQueryNode(config)) {
            const type = config.exprName.getText().trim();
            // Checks if the file exports the mapper
            if (!fn.getSourceFile().statements.find((s) => 
            // export function
            ((0, nodes_1.isExportedFunction)(s) && s.name?.getText().trim() === type) ||
                // export const/let/var
                ((0, nodes_1.isExportedVariable)(s) && s.declarationList.declarations[0]?.name.getText().trim() === type))) {
                throw new common_1.RouteMapperNotExportedError(config);
            }
            route.options = `${common_1.kControllerName}.${type}($1)`;
            return {
                name: ThisParameterParser.name,
                value: '',
                ignore: true
            };
        }
        // Maps all typeof references
        for (const element of config.elements) {
            if (!ts_json_schema_generator_1.ts.isTypeQueryNode(element)) {
                throw new common_1.InvalidParameterUsageError('The `this` parameter must only have `typeof` references inside its tuple.', param.type || param);
            }
            const type = element.exprName.getText().trim();
            // Checks if the file exports the mapper
            if (!fn.getSourceFile().statements.find((s) => 
            // export function
            ((0, nodes_1.isExportedFunction)(s) && s.name?.getText().trim() === type) ||
                // export const/let/var
                ((0, nodes_1.isExportedVariable)(s) && s.declarationList.declarations[0]?.name.getText().trim() === type))) {
                throw new common_1.RouteMapperNotExportedError(config);
            }
            if (!route.options) {
                route.options = '$1';
            }
            route.options = `${common_1.kControllerName}.${type}(${route.options})`;
        }
        // This parameter is synthetic, so this result will not be used.
        return {
            name: ThisParameterParser.name,
            value: '',
            ignore: true
        };
    }
}
exports.ThisParameterParser = ThisParameterParser;
//# sourceMappingURL=this.js.map