﻿"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SchemasProviderParser = void 0;
const tslib_1 = require("tslib");
const common_1 = require("@kitajs/common");
const path_1 = tslib_1.__importDefault(require("path"));
class SchemasProviderParser {
    checker;
    schemaBuilder;
    constructor(checker, schemaBuilder) {
        this.checker = checker;
        this.schemaBuilder = schemaBuilder;
    }
    /** Default provider handles all files. */
    supports(file) {
        return path_1.default.basename(file.fileName) === 'schemas.ts';
    }
    async parse(source) {
        const symbol = this.checker.getSymbolAtLocation(source);
        if (!symbol) {
            throw new common_1.CannotCreateNodeTypeError(source, 'Could not find symbol for source file');
        }
        const exports = this.checker.getExportsOfModule(symbol);
        for (const exportedNode of exports) {
            const originalNode = exportedNode.declarations?.[0] || exportedNode.valueDeclaration;
            const type = this.checker.getTypeAtLocation(originalNode);
            const typeNode = this.checker.typeToTypeNode(type, undefined, undefined);
            if (!typeNode) {
                throw new common_1.CannotCreateNodeTypeError(source, 'Could not find node for exported symbol');
            }
            const schema = this.schemaBuilder.createTypeSchema(typeNode);
            if (schema &&
                //@ts-expect-error - always define a
                !schema.name) {
                // @ts-expect-error - try to find a name
                schema.name = originalNode?.name?.getText();
            }
            try {
                // Applies to a custom definition
                this.schemaBuilder.appendChildDefinitions(schema, common_1.kSchemaDefinitions);
            }
            catch (error) {
                throw new common_1.CannotCreateNodeTypeError(originalNode, error);
            }
        }
        return undefined;
    }
}
exports.SchemasProviderParser = SchemasProviderParser;
//# sourceMappingURL=schema.js.map