﻿"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.correctFormatterChildrenOrder = exports.removeFormatterDefinitions = exports.mergeSchema = void 0;
const tslib_1 = require("tslib");
const deepmerge_1 = tslib_1.__importDefault(require("deepmerge"));
/** Combines a route schema with a new schema. */
function mergeSchema(route, schema) {
    route.schema = (0, deepmerge_1.default)(route.schema, schema);
}
exports.mergeSchema = mergeSchema;
/**
 * Creates a type formatter that removes the `#/definitions/` prefix from `$ref` properties.
 *
 * This was a proposed option in ts-json-schema-generator, buy ruled out as out of scope.
 *
 * @see https://github.com/vega/ts-json-schema-generator/pull/1386
 */
function removeFormatterDefinitions(typeFormatter) {
    const getDefinition = typeFormatter.getDefinition.bind(typeFormatter);
    typeFormatter.getDefinition = function (type) {
        // Calls the original getDefinition function.
        const def = getDefinition(type);
        // Remove the `#/definitions/` prefix from the $ref property.
        if (def.$ref) {
            def.$ref = def.$ref.replace(/^\#\/definitions\//g, '');
        }
        return def;
    };
    return typeFormatter;
}
exports.removeFormatterDefinitions = removeFormatterDefinitions;
/**
 * This is a workaround to move the response definition field to the end of the object.
 *
 * It's necessary for when the response references another definition that was not defined yet.
 *
 * Which throws a reference error at runtime because the referenced def was going to be defined after the response
 * definition
 */
function correctFormatterChildrenOrder(typeFormatter) {
    const getChildren = typeFormatter.getChildren.bind(typeFormatter);
    typeFormatter.getChildren = function (type) {
        const children = getChildren(type);
        // The original type is always the first child
        const first = children.shift();
        first && children.push(first);
        return children;
    };
    return typeFormatter;
}
exports.correctFormatterChildrenOrder = correctFormatterChildrenOrder;
//# sourceMappingURL=helpers.js.map