﻿import { ts } from 'ts-json-schema-generator';
/** Gets the trimmed type name. */
export declare function getTypeName(type?: ts.Node): string | undefined;
/** Gets the parameter type name. */
export declare function getTypeNodeName(param: Pick<ts.ParameterDeclaration, 'type'>): string | undefined;
/** Gets the parameter type name. */
export declare function getIdentifierName(param: ts.BindingName): string;
/**
 * Tries to resolve the parameter name, either by a string literal specified by {@linkcode genericIndex} or the parameter
 * name.
 *
 * @param genericIndex If the provided parameter is a NodeWithTypeArguments, which generic we should use?
 */
export declare function getParameterName(node: ts.ParameterDeclaration, genericIndex: number): string;
/** Gets the parameter type generics. */
export declare function getParameterGenerics(param: ts.ParameterDeclaration): ts.NodeArray<ts.TypeNode> | never[];
/** If the provided function has a `this` parameter. */
export declare function hasThisParameter(fn: ts.FunctionDeclaration): boolean | undefined;
/** Returns true if the parameter is optional or has a initializer. */
export declare function isParamOptional(param: ts.ParameterDeclaration): boolean;
/** Finds the return type of a declaration or creates one if it doesn't exist. */
export declare function getReturnType(node: ts.SignatureDeclaration, typeChecker: ts.TypeChecker): ts.TypeNode;
export declare function isExportedVariable(node: ts.Node): node is ts.VariableStatement & {
    modifiers: ts.NodeArray<ts.ModifierLike>;
};
/** Returns true if the provided node is a exported function. */
export declare function isExportedFunction(node: ts.Node): node is ts.FunctionDeclaration & {
    modifiers: ts.NodeArray<ts.ModifierLike>;
};
/** Returns true if the provided node is a default exported function. */
export declare function isDefaultExportFunction(node: ts.Node): node is ts.FunctionDeclaration & {
    modifiers: ts.NodeArray<ts.ModifierLike>;
};
/** Returns true if the provided node is a **default or not exported** function. */
export declare function isExportFunction(node: ts.Node): node is ts.FunctionDeclaration & {
    modifiers: ts.NodeArray<ts.ModifierLike>;
};
/** Asserts if this node identifier name */
export declare function nodeNameEquals(node: {
    name?: ts.Identifier;
}, name: string): boolean;
/** If the provided type is a promise, returns the type of the promise, otherwise returns the type itself. */
export declare function unwrapPromiseType(type: ts.TypeNode): ts.TypeNode;
//# sourceMappingURL=nodes.d.ts.map