﻿"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.toTsPath = exports.cwdRelative = exports.walk = void 0;
const tslib_1 = require("tslib");
const fs_1 = tslib_1.__importDefault(require("fs"));
const path_1 = tslib_1.__importDefault(require("path"));
/** Synchronously walks the given directory and returns all files in it. */
function walk(dir) {
    try {
        return (fs_1.default
            .readdirSync(dir, { recursive: true, withFileTypes: true })
            .filter((f) => f.isFile())
            // Node <20 f.path may be undefined
            .map((f) => path_1.default.resolve(f.path || dir, f.name)));
    }
    catch (e) {
        // Ignore if folder does not exist
        if (e.code === 'ENOENT') {
            return [];
        }
        throw e;
    }
}
exports.walk = walk;
/**
 * Makes the given path relative to the current working directory (`./`).
 *
 * Posix: `./<dir>`, in windows: `.\\<dir>`
 */
function cwdRelative(p) {
    return path_1.default.join('./') + path_1.default.normalize(p);
}
exports.cwdRelative = cwdRelative;
const WIN32_PATH_SEP = /\\/g;
/** Replaces all path separators with `/` to make it compatible with TS compiler. */
function toTsPath(p) {
    // TS compiler always uses `/` as path separator
    if (path_1.default.sep === path_1.default.win32.sep) {
        return p.replace(WIN32_PATH_SEP, '/');
    }
    return p;
}
exports.toTsPath = toTsPath;
//# sourceMappingURL=paths.js.map