﻿"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseUrl = void 0;
const tslib_1 = require("tslib");
const common_1 = require("@kitajs/common");
const node_path_1 = tslib_1.__importDefault(require("node:path"));
const WIN32_SEP_REGEX = /\\/g;
function parseUrl(filepath, config) {
    let strip = filepath;
    // Strips any possible regex that the user might have added
    strip = node_path_1.default.relative(node_path_1.default.join(config.src, common_1.kRoutesFolder), filepath);
    // Keeps everything before first . (removes extensions like .test.ts or .js)
    strip = strip.slice(0, -node_path_1.default.extname(strip).length);
    // Replaces windows separators with /
    strip = strip.replace(WIN32_SEP_REGEX, '/');
    // Replaces spaces with underlines
    strip = strip.replace(/\s/g, '_');
    // Replaces [...] to *
    let url = strip.replace(/\[\.{3}\]/g, '*');
    // Replaces [param] syntax to :param
    url = url.replace(/\[(.+?)\]/g, ':$1');
    // Removes index from name
    url = url.replace(/(\/|^)index(\/|$)/g, '/');
    // Remove trailing slash
    if (url[url.length - 1] === '/') {
        url = url.slice(0, -1);
    }
    return {
        // Adds leading slash
        url: `/${url}`,
        // Camel case paths or dash case paths
        routeId: strip
            // Replaces [...] to Wilcard
            .replace(/\[\.{3}\]/g, 'Wildcard')
            // Replaces other parameters to their name
            .replace(/\[(.+?)\]/g, '$1')
            .split('/')
            .flatMap((p) => p.split('-'))
            .map(common_1.capitalize)
            .join('') || 'Index'
    };
}
exports.parseUrl = parseUrl;
//# sourceMappingURL=string.js.map